;;; cgreek-menu.el --- menu bar configuration for classical Greek

;; Copyright (C) 2003, 2005, 2010
;; National Institute of Advanced Industrial Science and Technology (AIST)
;; Registration Number: H15PRO 109

;; Author: TAKAHASHI Naoto <ntakahas@m17n.org>
;; Keywords: multilingual, classical Greek, Unicode

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or (at
;; your option) any later version.

;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth
;; Floor, Boston, MA 02110-1301, USA.

;;; Code

(defvar menu-bar-cgreek-menu (make-sparse-keymap))

;;; open file

(define-key menu-bar-cgreek-menu [open-tex]
  '("Open TeX File" . cgreek-find-file-tex))

(define-key-after menu-bar-cgreek-menu [open-utf8]
  (cons "Open Unicode File"
	(lambda (filename)
	  (interactive "FFind Unicode file: ")
	  (let ((coding-system-for-read 'utf-8))
	    (find-file filename)
	    (set-buffer-modified-p nil)
	    (goto-char (point-min))))))

(define-key-after menu-bar-cgreek-menu [open-html]
  '("Open HTML File" . cgreek-find-file-html))

(define-key-after menu-bar-cgreek-menu [open-wingreek]
  '("Open WinGreek File" . cgreek-find-file-wingreek))

(define-key-after menu-bar-cgreek-menu [open-tlg]
  '("Open TLG CD-ROM" . cgreek-tlg-parse-authtab))

;;; save buffer

(define-key-after menu-bar-cgreek-menu [save]
  '("--"))

(define-key-after menu-bar-cgreek-menu [save-tex]
  '("Save TeX File" . cgreek-write-file-tex))

(define-key-after menu-bar-cgreek-menu [save-utf8]
  (cons "Save Unicode File"
	(lambda (filename)
	  (interactive
	   (list (if buffer-file-truename
		     (read-file-name "Write file: " buffer-file-truename)
		   (read-file-name "Write file: "
				   (cdr (assq 'default-directory
					      (buffer-local-variables)))
				   nil nil (buffer-name)))))
	  (let ((coding-system-for-write 'utf-8))
	    (write-file (expand-file-name filename))))))

(define-key-after menu-bar-cgreek-menu [save-html]
  '("Save HTML File" . cgreek-write-file-html))

;;; input methods

(defvar cgreek-greek-im "greek-mizuochi"
  "*Input method used for Greek.")

(defvar cgreek-latin-im "latin-1-postfix"
  "*Input method used for Latin.")

(defvar cgreek-local-im "japanese"
  "*Input method used for local language.")

(defvar cgreek-foreign-im "cyrillic-jcuken"
  "*Input method used for foreign language.")

(define-key-after menu-bar-cgreek-menu [language]
  '("--"))

(define-key-after menu-bar-cgreek-menu [greek]
  (cons "Input Greek"
	(lambda () (interactive) (set-input-method cgreek-greek-im))))

(define-key-after menu-bar-cgreek-menu [latin]
  (cons "Input Latin"
	(lambda () (interactive) (set-input-method cgreek-latin-im))))

(define-key-after menu-bar-cgreek-menu [local]
  (cons "Input Local Language"
	(lambda () (interactive) (set-input-method cgreek-local-im))))

(define-key-after menu-bar-cgreek-menu [foreign]
  (cons "Input Foreign Language"
	(lambda () (interactive) (set-input-method cgreek-foreign-im))))

;;; ps-print

(define-key-after menu-bar-cgreek-menu [print]
  '("--"))

(define-key-after menu-bar-cgreek-menu [print-buffer]
  '("Print Buffer" . ps-print-buffer))

(define-key-after menu-bar-cgreek-menu [print-region]
  '("Print Region" . ps-print-region))

;;; top

(define-key-after (lookup-key global-map [menu-bar]) [cgreek]
  (cons "CGreek" menu-bar-cgreek-menu) menu-bar-final-items)

;;; cgreek-menu.el ends here
