;;; cgreek-misc.el --- File I/O in miscellaneous formats

;; Copyright (C) 2003, 2005, 2010
;; National Institute of Advanced Industrial Science and Technology (AIST)
;; Registration Number: H15PRO 109

;; Author: TAKAHASHI Naoto <ntakahas@m17n.org>
;; Keywords: multilingual, classical Greek, Unicode, WinGreek

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or (at
;; your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth
;; Floor, Boston, MA 02110-1301, USA.

;;; Code:

;;; WinGreek

(defconst greek-wingreek-to-unicode-table
  [
   #x0000 #x0001 #x0002 #x0003 #x0004 #x0005 #x0006 #x0007 
   #x0008 #x0009 #x000a #x000b #x000c #x000d #x000e #x000f 
   #x0010 #x0011 #x0012 #x0013 #x0014 #x0015 #x0016 #x0017 
   #x0018 #x0019 #x001a #x001b #x001c #x001d #x001e #x001f 
   #x0020 #x2199 #x03e1 #x03dd #x03db #x03d9 #x03d8 #x1fbf
   #x0028 #x0029 #x002a #x203b #x002c #x002d #x002e #x1ffd
   #x0030 #x0031 #x0032 #x0033 #x0034 #x0035 #x0036 #x0037
   #x0038 #x0039 #x0387 #x037e #x003c #x003d #x003e #x003f
   #x00a8 #x0391 #x0392 #x03a7 #x0394 #x0395 #x03a6 #x0393
   #x0397 #x0399 #x1ff3 #x039a #x039b #x039c #x039d #x039f
   #x03a0 #x0398 #x03a1 #x03a3 #x03a4 #x03a5 #x1fc3 #x03a9
   #x039e #x03a8 #x0396 #x005b #x1fef #x005d #x1fc0 #x005f
   #x1ffe #x03b1 #x03b2 #x03c7 #x03b4 #x03b5 #x03c6 #x03b3
   #x03b7 #x03b9 #x03c2 #x03ba #x03bb #x03bc #x03bd #x03bf
   #x03c0 #x03b8 #x03c1 #x03c3 #x03c4 #x03c5 #x1fb3 #x03c9
   #x03be #x03c8 #x03b6 #x007b #x007c #x007d #x007e #x007f
   #x0020 #x0020 #x0020 #x1f31 #x1f30 #x1f77 #x1f35 #x1f34
   #x1f76 #x1f33 #x1f32 #x1fd6 #x1f37 #x1f36 #x03ca #x1fd3
   #x1fd2 #x1fdf #x1fcf #x1fde #x1fce #x1fdd #x1fcd #x1fee
   #x1f11 #x1f10 #x1f73 #x1f15 #x1f14 #x1f72 #x1f13 #x1f12
   #x1fed #x1f01 #x1f00 #x1f71 #x1f05 #x1f04 #x1f70 #x1f03
   #x1f02 #x1fb6 #x1f07 #x1f06 #x1f81 #x1f80 #x1fb4 #x1f85
   #x1f84 #x1fb2 #x1f83 #x1f82 #x1fb7 #x1f87 #x1f86 #x1fe5
   #x1fe4 #x1f21 #x1f20 #x1f75 #x1f25 #x1f24 #x1f74 #x1f23
   #x1f22 #x1fc6 #x1f27 #x1f26 #x037a #x1f91 #x1f90 #x1fc4
   #x1f95 #x1f94 #x1fc2 #x1f93 #x1f92 #x1fc7 #x1f97 #x1f96
   #x1f41 #x1f40 #x1f79 #x1f45 #x1f44 #x1f78 #x1f43 #x1f42
   #x1f51 #x1f50 #x1f7b #x1f55 #x1f54 #x1f7a #x1f53 #x1f52
   #x1fe6 #x1f57 #x1f56 #x03cb #x1fe3 #x1fe2 #x1f61 #x1f60
   #x1f7d #x1f65 #x1f64 #x1f7c #x1f63 #x1f62 #x1ff6 #x1f67
   #x1f66 #x1fa1 #x1fa0 #x1ff4 #x1fa5 #x1fa4 #x1ff2 #x1fa3
   #x1fa2 #x1ff7 #x1fa7 #x1fa6 #x0020 #x0020 #x0020 #x0020
   ]
  "Mapping table from WinGreek codepoints to Unicode codepoints."
  )

(let ((i 0)
      (vec (make-vector 256 0))
      table)
  (while (< i 256)
    (aset vec i (aref greek-wingreek-to-unicode-table i))
    (setq i (1+ i)))
  (setq table (make-translation-table-from-vector vec))
  (define-translation-table 'greek-wingreek-decode-table table)
  (define-translation-table 'greek-wingreek-encode-table
    (char-table-extra-slot table 0)))

(define-ccl-program ccl-decode-wingreek
  `(4
    ((loop
      (r0 = 0)
      (read r1)
      (if (r1 == #xfc)
	  ((write #x03b5)
	   (write #x0342)
	   (repeat))
	(if (r1 == #xfd)
	    ((write #x03bf)
	     (write #x0342)
	     (repeat))
	  ((translate-character greek-wingreek-decode-table r0 r1)
	   (write-multibyte-character r0 r1)
	   (repeat)))))))
  "CCL program to decode WinGreek.")

(define-ccl-program ccl-encode-wingreek
  `(1
    ((loop
      (read-multibyte-character r0 r1)
      (translate-character greek-wingreek-encode-table r0 r1)
      (write-repeat r1))))
  "CCL program to encode WinGreek.")

(define-coding-system
  'greek-wingreek
  "WinGreek 8-bit encoding for polytonic Greek."
  :mnemonic ?W :coding-type 'ccl
  :ccl-decoder 'ccl-decode-wingreek :ccl-encoder 'ccl-encode-wingreek
  :valids '((32 . 127) (131 . 253)))

(defun cgreek-find-file-wingreek (filename)
  "Edit file FILENAME encoded in WinGreek charset.
Switch to a buffer visiting file FILENAME,
creating one if none already exists."
  (interactive "FFind WinGreek file: ")
  (let ((coding-system-for-read 'greek-wingreek))
    (find-file filename)))

(defun cgreek-write-file-wingreek (filename)
  "Write current buffer into file FILENAME in WinGreek charset.
Makes buffer visit that file, and marks it not modified.
If the buffer is already visiting a file, you can specify
a directory name as FILENAME, to write a file of the same
old name in that directory."
  (interactive
   (list (if buffer-file-truename
	     (read-file-name "Write WinGreek file: " buffer-file-truename)
	   (read-file-name "Write WinGreek file: "
			   (cdr (assq 'default-directory
				      (buffer-local-variables)))
			   nil nil (buffer-name)))))
  (let ((coding-system-for-write 'greek-wingreek))
    (write-file (expand-file-name filename))))

;;; html

(defun cgreek-write-file-html (filename)
  "Write current buffer into file FILENAME using the HTML format.
Each Unicode character is converted into &#xxxx; when saiving.
Makes buffer visit that file, and marks it not modified.
If the buffer is already visiting a file, you can specify
a directory name as FILENAME, to write a file of the same
old name in that directory."
  (interactive
   (list (if buffer-file-truename
	     (read-file-name "Write HTML file: " buffer-file-truename)
	   (read-file-name "Write HTML file: "
			   (cdr (assq 'default-directory
				      (buffer-local-variables)))
			   nil nil (buffer-name)))))
  (let ((buf (current-buffer))
	(range (format "[%c-%c%c-%c]" #x00a0 #x00ff #x0100 #x24ff)))
    (with-temp-buffer
      (insert-buffer-substring buf)
      (while (re-search-backward range nil t)
	(insert (format "&#%d;" (following-char)))
	(delete-char 1))
      (write-file (expand-file-name filename)))
    (set-buffer-modified-p nil)))

(defun cgreek-find-file-html (filename)
  "Edit file FILENAME encoded in the HTML format.
Each &#xxxx; sequence is converted into the corresponding Unicode character.
Switch to a buffer visiting file FILENAME,
creating one if none already exists."
  (interactive "FFind HTML file: ")
  (find-file filename)
  (goto-char (point-min))
  (while (re-search-forward "&#\\([0-9]+\\);" nil t)
    (replace-match
     (char-to-string (string-to-number (match-string 1)))))
  (set-buffer-modified-p nil)
  (goto-char (point-min)))

(provide 'cgreek-misc)

;;; cgreek-misc.el ends here
