;;; greek.el --- robin packages for Greek -*- coding: utf-8; -*-

;; Copyright (C) 2003, 2005, 2010
;; National Institute of Advanced Industrial Science and Technology (AIST)
;; Registration Number: H15PRO 110

;; Author: TAKAHASHI Naoto <ntakahas@m17n.org>
;; Keywords: multilingual, Greek

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or (at
;; your option) any later version.

;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth
;; Floor, Boston, MA 02110-1301, USA.

;;; Code:

(robin-define-package "greek-mizuochi"
"The Mizuochi input method for classical Greek.

-------------------------------------
character     capital	      small
-------------------------------------
alpha		A		a
beta		B		b
gamma		G		g
delta		D		d
epsilon		E		e
zeta		Z		z
eta		H		h
theta		Q		q
iota		I		i
kappa		K		k
lamda		L		l
mu		M		m
nu		H		n
xi		X		x
omicron		O		o
pi		P		p
rho		R		r
sigma		S		s
final sigma			j
tau		T		t
upsilon		U		u
phi		F		f
chi		C		c
psi		Y		y
omega		W		w
-------------------------------------
sampi				!
digamma		#
stigma				$
koppa		&		%
-------------------------------------

------------------------
mark		key
------------------------
ypogegrammeni	J
psili		'  or  v
dasia		`  or  V
oxia		/
varia		?
perispomeni	\\  or  ^
dialytika	\"
ano teleia	:
erotimatiko	;
----------------------"

 ("!" ?ϡ) ; sampi
 ("#" ?ϝ) ; digamma
 ("$" ?ϛ) ; stigma
 ("%" ?ϙ) ; archaic koppa
 ("&" ?Ϙ) ; archaic KOPPA
 ("'" ?᾿) ("v" ?᾿) ; psili
 ("/" ?´) ; oxia
 (":" ?·) ; ano teleia
 (";" ?;) ; erotimatiko
 ("\"" ?¨) ; dialytika

 ("A" ?Α)
 ("B" ?Β)
 ("C" ?Χ)
 ("D" ?Δ)
 ("E" ?Ε)
 ("F" ?Φ)
 ("G" ?Γ)
 ("H" ?Η)
 ("I" ?Ι)
 ("wJ" ?ῳ)
 ("K" ?Κ)
 ("L" ?Λ)
 ("M" ?Μ)
 ("N" ?Ν)
 ("O" ?Ο)

 ("P" ?Π)
 ("Q" ?Θ)
 ("R" ?Ρ)
 ("S" ?Σ)
 ("T" ?Τ)
 ("U" ?Υ)
 ("hJ" ?ῃ)
 ("W" ?Ω)
 ("X" ?Ξ)
 ("Y" ?Ψ)
 ("Z" ?Ζ)
 ("?" ?`) ; varia
 ("\\" ?͂) ; #x0342 combining perispomeni
 ("\\" ?῀) ; #x1fc0 perispomeni
 ("^" ?͂) ; #x0342 combining perispomeni
 ("^" ?῀) ; #x1fc0 perispomeni

 ("`" ?῾) ("V" ?῾) ; dasia
 ("a" ?α)
 ("b" ?β)
 ("c" ?χ)
 ("d" ?δ)
 ("e" ?ε)
 ("f" ?φ)
 ("g" ?γ)
 ("h" ?η)
 ("i" ?ι)
 ("j" ?ς)
 ("k" ?κ)
 ("l" ?λ)
 ("m" ?μ)
 ("n" ?ν)
 ("o" ?ο)
 
 ("p" ?π)
 ("q" ?θ)
 ("r" ?ρ)
 ("s" ?σ)
 ("t" ?τ)
 ("u" ?υ)
 ("aJ" ?ᾳ)
 ("w" ?ω)
 ("x" ?ξ)
 ("y" ?ψ)
 ("z" ?ζ)

 ("i`" ?ἱ) ("iV" ?ἱ)
 ("i'" ?ἰ) ("iv" ?ἰ)
 ("i/" ?ί)
 ("i`/" ?ἵ) ("iV/" ?ἵ) ("i/`" ?ἵ) ("i/V" ?ἵ)
 ("i'/" ?ἴ) ("iv/" ?ἴ) ("i/'" ?ἴ) ("i/v" ?ἴ)
 ("i?" ?ὶ)
 ("i`?" ?ἳ) ("iV?" ?ἳ) ("i?`" ?ἳ) ("i?V" ?ἳ)
 ("i'?" ?ἲ) ("iv?" ?ἲ) ("i?'" ?ἲ) ("i?v" ?ἲ)
 ("i^"  ?ῖ) ("i\\" ?ῖ)
 ("i`^"  ?ἷ) ("i`\\" ?ἷ) ("iV^"  ?ἷ) ("iV\\" ?ἷ)
 ("i^`"  ?ἷ) ("i\\`" ?ἷ) ("i^V"  ?ἷ) ("i\\V" ?ἷ)
 ("i'^"  ?ἶ) ("i'\\" ?ἶ) ("iv^"  ?ἶ) ("iv\\" ?ἶ)
 ("i^'"  ?ἶ) ("i\\'" ?ἶ) ("i^v"  ?ἶ) ("i\\v" ?ἶ)
 ("i\"" ?ϊ)
 ("i/\"" ?ΐ) ("i\"/" ?ΐ)
 ("i?\"" ?ῒ) ("i\"?" ?ῒ)

 ("I`" ?Ἱ) ("IV" ?Ἱ)
 ("I'" ?Ἰ) ("Iv" ?Ἰ)
 ("I/" ?Ί)
 ("I`/" ?Ἵ) ("IV/" ?Ἵ) ("I/`" ?Ἵ) ("I/V" ?Ἵ)
 ("I'/" ?Ἴ) ("Iv/" ?Ἴ) ("I/'" ?Ἴ) ("I/v" ?Ἴ)
 ("I?" ?Ὶ)
 ("I`?" ?Ἳ) ("IV?" ?Ἳ) ("I?`" ?Ἳ) ("I?V" ?Ἳ)
 ("I'?" ?Ἲ) ("Iv?" ?Ἲ) ("I?'" ?Ἲ) ("I?v" ?Ἲ)
 ("I^"  ?ῖ) ("I\\" ?ῖ)
 ("I`^"  ?Ἷ) ("I`\\" ?Ἷ) ("IV^"  ?Ἷ) ("IV\\" ?Ἷ)
 ("I^`"  ?Ἷ) ("I\\`" ?Ἷ) ("I^V"  ?Ἷ) ("I\\V" ?Ἷ)
 ("I'^"  ?Ἶ) ("I'\\" ?Ἶ) ("Iv^"  ?Ἶ) ("Iv\\" ?Ἶ)
 ("I^'"  ?Ἶ) ("I\\'" ?Ἶ) ("I^v"  ?Ἶ) ("I\\v" ?Ἶ)
 ("I\"" ?Ϊ)
 ("I/\"" ?ΐ) ("I\"/" ?ΐ)
 ("I?\"" ?ῒ) ("I\"?" ?ῒ)

 ("e`" ?ἑ) ("eV" ?ἑ)
 ("e'" ?ἐ) ("ev" ?ἐ)
 ("e/" ?έ)
 ("e/`" ?ἕ) ("e/V" ?ἕ) ("e`/" ?ἕ) ("eV/" ?ἕ)
 ("e/'" ?ἔ) ("e/v" ?ἔ) ("e'/" ?ἔ) ("ev/" ?ἔ)
 ("e?" ?ὲ)
 ("e?`" ?ἓ) ("e?V" ?ἓ) ("e`?" ?ἓ) ("eV?" ?ἓ)
 ("e?'" ?ἒ) ("e?v" ?ἒ) ("e'?" ?ἒ) ("ev?" ?ἒ)

 ("E`" ?Ἑ) ("EV" ?Ἑ)
 ("E'" ?Ἐ) ("Ev" ?Ἐ)
 ("E/" ?Έ)
 ("E/`" ?Ἕ) ("E/V" ?Ἕ) ("E`/" ?Ἕ) ("EV/" ?Ἕ)
 ("E/'" ?Ἔ) ("E/v" ?Ἔ) ("E'/" ?Ἔ) ("Ev/" ?Ἔ)
 ("E?" ?Ὲ)
 ("E?`" ?Ἓ) ("E?V" ?Ἓ) ("E`?" ?Ἓ) ("EV?" ?Ἓ)
 ("E?'" ?Ἒ) ("E?v" ?Ἒ) ("E'?" ?Ἒ) ("Ev?" ?Ἒ)

 ("a`" ?ἁ) ("aV" ?ἁ)
 ("a'" ?ἀ) ("av" ?ἀ)
 ("a/" ?ά)
 ("a/`" ?ἅ) ("a/V" ?ἅ) ("a`/" ?ἅ) ("aV/" ?ἅ)
 ("a/'" ?ἄ) ("a/v" ?ἄ) ("a'/" ?ἄ) ("av/" ?ἄ)
 ("a?" ?ὰ)
 ("a?`" ?ἃ) ("a?V" ?ἃ) ("a`?" ?ἃ) ("aV?" ?ἃ)
 ("a?'" ?ἂ) ("a?v" ?ἂ) ("a'?" ?ἂ) ("av?" ?ἂ)
 ("a^"  ?ᾶ) ("a\\" ?ᾶ)
 ("a^`"  ?ἇ) ("a^V"  ?ἇ) ("a\\`" ?ἇ) ("a\\V" ?ἇ)
 ("a`^"  ?ἇ) ("aV^"  ?ἇ) ("a`\\" ?ἇ) ("aV\\" ?ἇ)
 ("a^'"  ?ἆ) ("a^v"  ?ἆ) ("a\\'" ?ἆ) ("a\\v" ?ἆ)
 ("a'^"  ?ἆ) ("av^"  ?ἆ) ("a'\\" ?ἆ) ("av\\" ?ἆ)

 ("A`" ?Ἁ) ("AV" ?Ἁ)
 ("A'" ?Ἀ) ("Av" ?Ἀ)
 ("A/" ?Ά)
 ("A/`" ?Ἅ) ("A/V" ?Ἅ) ("A`/" ?Ἅ) ("AV/" ?Ἅ)
 ("A/'" ?Ἄ) ("A/v" ?Ἄ) ("A'/" ?Ἄ) ("Av/" ?Ἄ)
 ("A?" ?Ὰ)
 ("A?`" ?Ἃ) ("A?V" ?Ἃ) ("A`?" ?Ἃ) ("AV?" ?Ἃ)
 ("A?'" ?Ἂ) ("A?v" ?Ἂ) ("A'?" ?Ἂ) ("Av?" ?Ἂ)
 ("A^"  ?ᾶ) ("A\\" ?ᾶ)
 ("A^`"  ?Ἇ) ("A^V"  ?Ἇ) ("A\\`" ?Ἇ) ("A\\V" ?Ἇ)
 ("A`^"  ?Ἇ) ("AV^"  ?Ἇ) ("A`\\" ?Ἇ) ("AV\\" ?Ἇ)
 ("A^'"  ?Ἆ) ("A^v"  ?Ἆ) ("A\\'" ?Ἆ) ("A\\v" ?Ἆ)
 ("A'^"  ?Ἆ) ("Av^"  ?Ἆ) ("A'\\" ?Ἆ) ("Av\\" ?Ἆ)

 ("aJ`" ?ᾁ) ("aJV" ?ᾁ)
 ("aJ'" ?ᾀ) ("aJv" ?ᾀ)
 ("aJ/" ?ᾴ)
 ("aJ/`" ?ᾅ) ("aJ/V" ?ᾅ) ("aJ`/" ?ᾅ) ("aJV/" ?ᾅ)
 ("aJ/'" ?ᾄ) ("aJ/v" ?ᾄ) ("aJ'/" ?ᾄ) ("aJv/" ?ᾄ)
 ("aJ?" ?ᾲ)
 ("aJ?`" ?ᾃ) ("aJ?V" ?ᾃ) ("aJ`?" ?ᾃ) ("aJV?" ?ᾃ)
 ("aJ?'" ?ᾂ) ("aJ?v" ?ᾂ) ("aJ'?" ?ᾂ) ("aJv?" ?ᾂ)
 ("aJ^"  ?ᾷ) ("aJ\\" ?ᾷ)
 ("aJ^`"  ?ᾇ) ("aJ^V"  ?ᾇ) ("aJ\\`" ?ᾇ) ("aJ\\V" ?ᾇ)
 ("aJ`^"  ?ᾇ) ("aJV^"  ?ᾇ) ("aJ`\\" ?ᾇ) ("aJV\\" ?ᾇ)
 ("aJ^'"  ?ᾆ) ("aJ^v"  ?ᾆ) ("aJ\\'" ?ᾆ) ("aJ\\v" ?ᾆ)
 ("aJ'^"  ?ᾆ) ("aJv^"  ?ᾆ) ("aJ'\\" ?ᾆ) ("aJv\\" ?ᾆ)

 ("AJ`" ?ᾉ) ("AJV" ?ᾉ)
 ("AJ'" ?ᾈ) ("AJv" ?ᾈ)
 ("AJ/" ?ᾴ)
 ("AJ/`" ?ᾍ) ("AJ/V" ?ᾍ) ("AJ`/" ?ᾍ) ("AJV/" ?ᾍ)
 ("AJ/'" ?ᾌ) ("AJ/v" ?ᾌ) ("AJ'/" ?ᾌ) ("AJv/" ?ᾌ)
 ("AJ?" ?ᾲ)
 ("AJ?`" ?ᾋ) ("AJ?V" ?ᾋ) ("AJ`?" ?ᾋ) ("AJV?" ?ᾋ)
 ("AJ?'" ?ᾊ) ("AJ?v" ?ᾊ) ("AJ'?" ?ᾊ) ("AJv?" ?ᾊ)
 ("AJ^"  ?ᾷ) ("AJ\\" ?ᾷ)
 ("AJ^`"  ?ᾏ) ("AJ^V"  ?ᾏ) ("AJ\\`" ?ᾏ) ("AJ\\V" ?ᾏ)
 ("AJ`^"  ?ᾏ) ("AJV^"  ?ᾏ) ("AJ`\\" ?ᾏ) ("AJV\\" ?ᾏ)
 ("AJ^'"  ?ᾎ) ("AJ^v"  ?ᾎ) ("AJ\\'" ?ᾎ) ("AJ\\v" ?ᾎ)
 ("AJ'^"  ?ᾎ) ("AJv^"  ?ᾎ) ("AJ'\\" ?ᾎ) ("AJv\\" ?ᾎ)

 ("r`" ?ῥ) ("rV" ?ῥ)
 ("r'" ?ῤ) ("rv" ?ῤ)

 ("R`" ?Ῥ) ("RV" ?Ῥ)

 ("h`" ?ἡ) ("hV" ?ἡ)
 ("h'" ?ἠ) ("hv" ?ἠ)
 ("h/" ?ή)
 ("h/`" ?ἥ) ("h/V" ?ἥ) ("h`/" ?ἥ) ("hV/" ?ἥ)
 ("h/'" ?ἤ) ("h/v" ?ἤ) ("h'/" ?ἤ) ("hv/" ?ἤ)
 ("h?" ?ὴ)
 ("h?`" ?ἣ) ("h?V" ?ἣ) ("h`?" ?ἣ) ("hV?" ?ἣ)
 ("h?'" ?ἢ) ("h?v" ?ἢ) ("h'?" ?ἢ) ("hv?" ?ἢ)
 ("h^"  ?ῆ) ("h\\" ?ῆ)
 ("h^`"  ?ἧ) ("h^V"  ?ἧ) ("h\\`" ?ἧ) ("h\\V" ?ἧ)
 ("h`^"  ?ἧ) ("h`\\" ?ἧ) ("hV^"  ?ἧ) ("hV\\" ?ἧ)
 ("h^'"  ?ἦ) ("h^v"  ?ἦ) ("h\\'" ?ἦ) ("h\\v" ?ἦ)
 ("h'^"  ?ἦ) ("h'\\" ?ἦ) ("hv^"  ?ἦ) ("hv\\" ?ἦ)

 ("H`" ?Ἡ) ("HV" ?Ἡ)
 ("H'" ?Ἠ) ("Hv" ?Ἠ)
 ("H/" ?Ή)
 ("H/`" ?Ἥ) ("H/V" ?Ἥ) ("H`/" ?Ἥ) ("HV/" ?Ἥ)
 ("H/'" ?Ἤ) ("H/v" ?Ἤ) ("H'/" ?Ἤ) ("Hv/" ?Ἤ)
 ("H?" ?Ὴ)
 ("H?`" ?Ἣ) ("H?V" ?Ἣ) ("H`?" ?Ἣ) ("HV?" ?Ἣ)
 ("H?'" ?Ἢ) ("H?V" ?Ἢ) ("H'?" ?Ἢ) ("HV?" ?Ἢ)
 ("H^"  ?ῆ) ("H\\" ?ῆ)
 ("H^`"  ?Ἧ) ("H^V"  ?Ἧ) ("H\\`" ?Ἧ) ("H\\V" ?Ἧ)
 ("H`^"  ?Ἧ) ("H`\\" ?Ἧ) ("HV^"  ?Ἧ) ("HV\\" ?Ἧ)
 ("H^'"  ?Ἦ) ("H^v"  ?Ἦ) ("H\\'" ?Ἦ) ("H\\v" ?Ἦ)
 ("H'^"  ?Ἦ) ("H'\\" ?Ἦ) ("Hv^"  ?Ἦ) ("Hv\\" ?Ἦ)

 ("J" ?ͺ) ; ypogegrammeni

 ("hJ`" ?ᾑ) ("hJV" ?ᾑ)
 ("hJ'" ?ᾐ) ("hJv" ?ᾐ)
 ("hJ/" ?ῄ)
 ("hJ`/" ?ᾕ) ("hJV/" ?ᾕ) ("hJ/`" ?ᾕ) ("hJ/V" ?ᾕ)
 ("hJ'/" ?ᾔ) ("hJv/" ?ᾔ) ("hJ/'" ?ᾔ) ("hJ/v" ?ᾔ)
 ("hJ?" ?ῂ)
 ("hJ`?" ?ᾓ) ("hJV?" ?ᾓ) ("hJ?`" ?ᾓ) ("hJ?V" ?ᾓ)
 ("hJ'?" ?ᾒ) ("hJv?" ?ᾒ) ("hJ?'" ?ᾒ) ("hJ?v" ?ᾒ)
 ("hJ^"  ?ῇ) ("hJ\\" ?ῇ)
 ("hJ`^"  ?ᾗ) ("hJ`\\" ?ᾗ) ("hJV^"  ?ᾗ) ("hJV\\" ?ᾗ)
 ("hJ^`"  ?ᾗ) ("hJ\\`" ?ᾗ) ("hJ^V"  ?ᾗ) ("hJ\\V" ?ᾗ)
 ("hJ'^"  ?ᾖ) ("hJ'\\" ?ᾖ) ("hJv^"  ?ᾖ) ("hJv\\" ?ᾖ)
 ("hJ^'"  ?ᾖ) ("hJ\\'" ?ᾖ) ("hJ^v"  ?ᾖ) ("hJ\\v" ?ᾖ)

 ("HJ`" ?ᾙ) ("HJV" ?ᾙ)
 ("HJ'" ?ᾘ) ("HJv" ?ᾘ)
 ("HJ/" ?ῄ)
 ("HJ`/" ?ᾝ) ("HJV/" ?ᾝ) ("HJ/`" ?ᾝ) ("HJ/V" ?ᾝ)
 ("HJ'/" ?ᾜ) ("HJv/" ?ᾜ) ("HJ/'" ?ᾜ) ("HJ/v" ?ᾜ)
 ("HJ?" ?ῂ)
 ("HJ`?" ?ᾛ) ("HJV?" ?ᾛ) ("HJ?`" ?ᾛ) ("HJ?V" ?ᾛ)
 ("HJ'?" ?ᾚ) ("HJv?" ?ᾚ) ("HJ?'" ?ᾚ) ("HJ?v" ?ᾚ)
 ("HJ^"  ?ῇ) ("HJ\\" ?ῇ)
 ("HJ`^"  ?ᾟ) ("HJ`\\" ?ᾟ) ("HJV^"  ?ᾟ) ("HJV\\" ?ᾟ)
 ("HJ^`"  ?ᾟ) ("HJ\\`" ?ᾟ) ("HJ^V"  ?ᾟ) ("HJ\\V" ?ᾟ)
 ("HJ'^"  ?ᾞ) ("HJ'\\" ?ᾞ) ("HJv^"  ?ᾞ) ("HJv\\" ?ᾞ)
 ("HJ^'"  ?ᾞ) ("HJ\\'" ?ᾞ) ("HJ^v"  ?ᾞ) ("HJ\\v" ?ᾞ)

 ("o`" ?ὁ) ("oV" ?ὁ)
 ("o'" ?ὀ) ("ov" ?ὀ)
 ("o/" ?ό)
 ("o/`" ?ὅ) ("o/V" ?ὅ) ("o`/" ?ὅ) ("oV/" ?ὅ)
 ("o/'" ?ὄ) ("o/v" ?ὄ) ("o'/" ?ὄ) ("ov/" ?ὄ)
 ("o?" ?ὸ)
 ("o?`" ?ὃ) ("o?V" ?ὃ) ("o`?" ?ὃ) ("oV?" ?ὃ)
 ("o?'" ?ὂ) ("o?v" ?ὂ) ("o'?" ?ὂ) ("ov?" ?ὂ)

 ("O`" ?Ὁ) ("OV" ?Ὁ)
 ("O'" ?Ὀ) ("Ov" ?Ὀ)
 ("O/" ?Ό)
 ("O/`" ?Ὅ) ("O/V" ?Ὅ) ("O`/" ?Ὅ) ("OV/" ?Ὅ)
 ("O/'" ?Ὄ) ("O/v" ?Ὄ) ("O'/" ?Ὄ) ("Ov/" ?Ὄ)
 ("O?" ?Ὸ)
 ("O?`" ?Ὃ) ("O?V" ?Ὃ) ("O`?" ?Ὃ) ("OV?" ?Ὃ)
 ("O?'" ?Ὂ) ("O?v" ?Ὂ) ("O'?" ?Ὂ) ("Ov?" ?Ὂ)

 ("u`" ?ὑ) ("uV" ?ὑ)
 ("u'" ?ὐ) ("uv" ?ὐ)
 ("u/" ?ύ)
 ("u/`" ?ὕ) ("u/V" ?ὕ) ("u`/" ?ὕ) ("uV/" ?ὕ)
 ("u/'" ?ὔ) ("u/v" ?ὔ) ("u'/" ?ὔ) ("uv/" ?ὔ)
 ("u?" ?ὺ)
 ("u?`" ?ὓ) ("u?V" ?ὓ) ("u`?" ?ὓ) ("uV?" ?ὓ)
 ("u?'" ?ὒ) ("u?v" ?ὒ) ("u'?" ?ὒ) ("uv?" ?ὒ)
 ("u^"  ?ῦ) ("u\\" ?ῦ)
 ("u^`"  ?ὗ) ("u^V"  ?ὗ) ("u\\`" ?ὗ) ("u\\V" ?ὗ)
 ("u`^"  ?ὗ) ("uV^"  ?ὗ) ("u`\\" ?ὗ) ("uV\\" ?ὗ)
 ("u^'"  ?ὖ) ("u^v"  ?ὖ) ("u\\'" ?ὖ) ("u\\v" ?ὖ)
 ("u'^"  ?ὖ) ("uv^"  ?ὖ) ("u'\\" ?ὖ) ("uv\\" ?ὖ)
 ("u\"" ?ϋ)
 ("u\"/" ?ΰ) ("u/\"" ?ΰ)
 ("u\"?" ?ῢ) ("u?\"" ?ῢ)

 ("U`" ?Ὑ) ("UV" ?Ὑ)
 ("U/" ?Ύ)
 ("U/`" ?Ὕ) ("U/V" ?Ὕ) ("U`/" ?Ὕ) ("UV/" ?Ὕ)
 ("U?" ?Ὺ)
 ("U?`" ?Ὓ) ("U?V" ?Ὓ) ("U`?" ?Ὓ) ("UV?" ?Ὓ)
 ("U^`"  ?Ὗ) ("U^V"  ?Ὗ) ("U\\`" ?Ὗ) ("U\\V" ?Ὗ)
 ("U`^"  ?Ὗ) ("UV^"  ?Ὗ) ("U`\\" ?Ὗ) ("UV\\" ?Ὗ)
 ("U\"" ?Ϋ)
 
 ("w`" ?ὡ) ("wV" ?ὡ)
 ("w'" ?ὠ) ("wv" ?ὠ)
 ("w/" ?ώ)
 ("w/`" ?ὥ) ("w/V" ?ὥ) ("w`/" ?ὥ) ("wV/" ?ὥ)
 ("w/'" ?ὤ) ("w/v" ?ὤ) ("w'/" ?ὤ) ("wv/" ?ὤ)
 ("w?" ?ὼ)
 ("w?`" ?ὣ) ("w?V" ?ὣ) ("w`?" ?ὣ) ("wV?" ?ὣ)
 ("w?'" ?ὢ) ("w?v" ?ὢ) ("w'?" ?ὢ) ("wv?" ?ὢ)
 ("w^"  ?ῶ) ("w\\" ?ῶ)
 ("w^`"  ?ὧ) ("w^V"  ?ὧ) ("w\\`" ?ὧ) ("w\\V" ?ὧ)
 ("w`^"  ?ὧ) ("wV^"  ?ὧ) ("w`\\" ?ὧ) ("wV\\" ?ὧ)
 ("w^'"  ?ὦ) ("w^v"  ?ὦ) ("w\\'" ?ὦ) ("w\\v" ?ὦ)
 ("w'^"  ?ὦ) ("wv^"  ?ὦ) ("w'\\" ?ὦ) ("wv\\" ?ὦ)
 
 ("W`" ?Ὡ) ("WV" ?Ὡ)
 ("W'" ?Ὠ) ("Wv" ?Ὠ)
 ("W/" ?Ώ)
 ("W/`" ?Ὥ) ("W/V" ?Ὥ) ("W`/" ?Ὥ) ("WV/" ?Ὥ)
 ("W/'" ?Ὤ) ("W/v" ?Ὤ) ("W'/" ?Ὤ) ("Wv/" ?Ὤ)
 ("W?" ?Ὼ)
 ("W?`" ?Ὣ) ("W?V" ?Ὣ) ("W`?" ?Ὣ) ("WV?" ?Ὣ)
 ("W?'" ?Ὢ) ("W?v" ?Ὢ) ("W'?" ?Ὢ) ("Wv?" ?Ὢ)
 ("W^`"  ?Ὧ) ("W^V"  ?Ὧ) ("W\\`" ?Ὧ) ("W\\V" ?Ὧ)
 ("W`^"  ?Ὧ) ("WV^"  ?Ὧ) ("W`\\" ?Ὧ) ("WV\\" ?Ὧ)
 ("W^'"  ?Ὦ) ("W^v"  ?Ὦ) ("W\\'" ?Ὦ) ("W\\v" ?Ὦ)
 ("W'^"  ?Ὦ) ("Wv^"  ?Ὦ) ("W'\\" ?Ὦ) ("Wv\\" ?Ὦ)

 ("wJ`" ?ᾡ) ("wJV" ?ᾡ)
 ("wJ'" ?ᾠ) ("wJv" ?ᾠ)
 ("wJ/" ?ῴ)
 ("wJ/`" ?ᾥ) ("wJ/V" ?ᾥ) ("wJ`/" ?ᾥ) ("wJV/" ?ᾥ)
 ("wJ/'" ?ᾤ) ("wJ/v" ?ᾤ) ("wJ'/" ?ᾤ) ("wJv/" ?ᾤ)
 ("wJ?" ?ῲ)
 ("wJ?`" ?ᾣ) ("wJ?V" ?ᾣ) ("wJ`?" ?ᾣ) ("wJV?" ?ᾣ)
 ("wJ?'" ?ᾢ) ("wJ?v" ?ᾢ) ("wJ'?" ?ᾢ) ("wJv?" ?ᾢ)
 ("wJ^"  ?ῷ) ("wJ\\" ?ῷ)
 ("wJ^`"  ?ᾧ) ("wJ^V"  ?ᾧ) ("wJ\\`" ?ᾧ) ("wJ\\V" ?ᾧ)
 ("wJ`^"  ?ᾧ) ("wJV^"  ?ᾧ) ("wJ`\\" ?ᾧ) ("wJV\\" ?ᾧ)
 ("wJ^'"  ?ᾦ) ("wJ^v"  ?ᾦ) ("wJ\\'" ?ᾦ) ("wJ\\v" ?ᾦ)
 ("wJ'^"  ?ᾦ) ("wJv^"  ?ᾦ) ("wJ'\\" ?ᾦ) ("wJv\\" ?ᾦ)
 ("WJ^"  ?ῷ) ("WJ\\" ?ῷ)

 ("^`"  ?῟) ("^V"  ?῟) ("\\`" ?῟) ("\\V" ?῟)
 ("`^"  ?῟) ("V^"  ?῟) ("`\\" ?῟) ("V\\" ?῟)
 ("^'"  ?῏) ("^v"  ?῏) ("\\'" ?῏) ("\\v" ?῏)
 ("'^"  ?῏) ("v^"  ?῏) ("'\\" ?῏) ("v\\" ?῏)
 ("/`" ?῞) ("/V" ?῞) ("`/" ?῞) ("V/" ?῞)
 ("/'" ?῎) ("/v" ?῎) ("'/" ?῎) ("v/" ?῎)
 ("?`" ?῝) ("?V" ?῝) ("`?" ?῝) ("V?" ?῝)
 ("?'" ?῍) ("?v" ?῍) ("'?" ?῍) ("v?" ?῍)
 ("\"/" ?΅) ("/\"" ?΅)
 ("\"?" ?῭) ("?\"" ?῭)

 ("e^" "ε͂") ("e\\" "ε͂") ; epsilon + combining perispomeni (#x0342)
 ("o^" "ο͂") ("o\\" "ο͂") ; omicron + combining perispomeni (#x0342)
 )

(register-input-method
 "greek-mizuochi" "Greek"
 'robin-use-package "cg"
 "The Mizuochi input method for classical Greek.")

(robin-define-package "greek-ibycus4"
 "The Ibycus4 input method for classical Greek.
Mainly used for transliteration."

 ("((" ?\() ("{((}" ?\() ; #x0028
 ("))" ?\)) ("{))}" ?\)) ; #x0029
 ("<<" ?«) ; #x00ab
 (">>" ?») ; #x00bb

 ("-" ?‐) ; #x2010
 ("---" ?—) ; #x2014
 ("||" ?‖) ; #x2016
 ("`" ?‘) ("{`}" ?‘) ; #x2018
 ("'" ?’) ("{}{'}" ?’) ; #x2019
 ("``" ?“) ("{``}" ?“) ; #x201c
 ("''" ?”) ("{''}" ?”) ; #x201d
 ("\\dag" ?†) ("{\\dag}" ?†) ; #x2020
 ("\\ddag" ?‡) ("{\\ddag}" ?‡) ; #x2021
 ("<" ?‹) ; #x2039
 (">" ?›) ; #x203a
 ("$\\leftarrow$" ?←) ; #x2190
 ("$\\rightarrow$" ?→) ; #x2192

 ("|" ?ͺ) ; #x037a ; ypogegrammeni
 ("?" ?;) ; #x037e ; erotimatiko
 ("'" ?΄) ; #x0384 ; tonos
 ("+'" ?΅) ; #x0385 ; dialytika tonos
 ("A'" ?Ά)
 (";" ?·) ; #x0387 ; ano teleia
 ("E'" ?Έ)
 ("H'" ?Ή)
 ("I'" ?Ί)
 ("O'" ?Ό)
 ("U'" ?Ύ)
 ("W'" ?Ώ)
 ("i+'" ?ΐ)

 ("A" ?Α)
 ("B" ?Β)
 ("G" ?Γ)
 ("D" ?Δ)
 ("E" ?Ε)
 ("Z" ?Ζ)
 ("H" ?Η)
 ("Q" ?Θ)
 ("I" ?Ι)
 ("K" ?Κ)
 ("L" ?Λ)
 ("M" ?Μ)
 ("N" ?Ν)
 ("C" ?Ξ)
 ("O" ?Ο)
 ("P" ?Π)
 ("R" ?Ρ)
 ("S" ?Σ)
 ("T" ?Τ)
 ("U" ?Υ)
 ("F" ?Φ)
 ("X" ?Χ)
 ("Y" ?Ψ)
 ("W" ?Ω)

 ("I+" ?Ϊ)
 ("U+" ?Ϋ)
 ("a'" ?ά)
 ("e'" ?έ)
 ("h'" ?ή)
 ("i'" ?ί)
 ("u+'" ?ΰ)

 ("a" ?α)
 ("b" ?β)
 ("g" ?γ)
 ("d" ?δ)
 ("e" ?ε)
 ("z" ?ζ)
 ("h" ?η)
 ("q" ?θ)
 ("i" ?ι)
 ("k" ?κ)
 ("l" ?λ)
 ("m" ?μ)
 ("n" ?ν)
 ("c" ?ξ)
 ("o" ?ο)
 ("p" ?π)
 ("r" ?ρ)
 ("j" ?ς) ("s " "ς ") ("s," "ς,") ("s." "ς.") ("s?" "ς;") ("s;" "ς·")
 ("s" ?σ) ("s|" ?σ)
 ("t" ?τ)
 ("u" ?υ)
 ("f" ?φ)
 ("x" ?χ)
 ("y" ?ψ)
 ("w" ?ω)

 ("i+" ?ϊ)
 ("u+" ?ϋ)
 ("o'" ?ό)
 ("u'" ?ύ)
 ("w'" ?ώ)

 ("K+" ?Ϙ) ; ARCHAIC KOPPA
 ("k+" ?ϙ) ; archaic koppa
 ("V" ?Ϝ) ; DIGAMMA
 ("v" ?ϝ) ; digamma
; ("S+" ?Ϡ) ; SAMPI (not available in Ibycus4)
 ("s+" ?ϡ) ; sampi
 ("c+" ?ϲ) ; lunate sigma
 ("C+" ?Ϲ) ; LUNATE SIGMA

 ("a)" ?ἀ)
 ("a(" ?ἁ)
 ("a)`" ?ἂ)
 ("a(`" ?ἃ)
 ("a)'" ?ἄ)
 ("a('" ?ἅ)
 ("a)=" ?ἆ)
 ("a(=" ?ἇ)

 (")A" ?Ἀ)
 ("(A" ?Ἁ)
 (")`A" ?Ἂ)
 ("(`A" ?Ἃ)
 (")'A" ?Ἄ)
 ("('A" ?Ἅ)
 (")=A" ?Ἆ)
 ("(=A" ?Ἇ)

 ("e)" ?ἐ)
 ("e(" ?ἑ)
 ("e)`" ?ἒ)
 ("e(`" ?ἓ)
 ("e)'" ?ἔ)
 ("e('" ?ἕ)

 (")E" ?Ἐ)
 ("(E" ?Ἑ)
 (")`E" ?Ἒ)
 ("(`E" ?Ἓ)
 (")'E" ?Ἔ)
 ("('E" ?Ἕ)

 ("h)" ?ἠ)
 ("h(" ?ἡ)
 ("h)`" ?ἢ)
 ("h(`" ?ἣ)
 ("h)'" ?ἤ)
 ("h('" ?ἥ)
 ("h)=" ?ἦ)
 ("h(=" ?ἧ)

 (")H" ?Ἠ)
 ("(H" ?Ἡ)
 (")`H" ?Ἢ)
 ("(`H" ?Ἣ)
 (")'H" ?Ἤ)
 ("('H" ?Ἥ)
 (")=H" ?Ἦ)
 ("(=H" ?Ἧ)

 ("i)" ?ἰ)
 ("i(" ?ἱ)
 ("i)`" ?ἲ)
 ("i(`" ?ἳ)
 ("i)'" ?ἴ)
 ("i('" ?ἵ)
 ("i)=" ?ἶ)
 ("i(=" ?ἷ)

 (")I" ?Ἰ)
 ("(I" ?Ἱ)
 (")`I" ?Ἲ)
 ("(`I" ?Ἳ)
 (")'I" ?Ἴ)
 ("('I" ?Ἵ)
 (")=I" ?Ἶ)
 ("(=I" ?Ἷ)

 ("o)" ?ὀ)
 ("o(" ?ὁ)
 ("o)`" ?ὂ)
 ("o(`" ?ὃ)
 ("o)'" ?ὄ)
 ("o('" ?ὅ)

 (")O" ?Ὀ)
 ("(O" ?Ὁ)
 (")`O" ?Ὂ)
 ("(`O" ?Ὃ)
 (")'O" ?Ὄ)
 ("('O" ?Ὅ)

 ("u)" ?ὐ)
 ("u(" ?ὑ)
 ("u)`" ?ὒ)
 ("u(`" ?ὓ)
 ("u)'" ?ὔ)
 ("u('" ?ὕ)
 ("u)=" ?ὖ)
 ("u(=" ?ὗ)

 ("(U" ?Ὑ)
 ("(`U" ?Ὓ)
 ("('U" ?Ὕ)
 ("(=U" ?Ὗ)

 ("w)" ?ὠ)
 ("w(" ?ὡ)
 ("w)`" ?ὢ)
 ("w(`" ?ὣ)
 ("w)'" ?ὤ)
 ("w('" ?ὥ)
 ("w)=" ?ὦ)
 ("w(=" ?ὧ)

 (")W" ?Ὠ)
 ("(W" ?Ὡ)
 (")`W" ?Ὢ)
 ("(`W" ?Ὣ)
 (")'W" ?Ὤ)
 ("('W" ?Ὥ)
 (")=W" ?Ὦ)
 ("(=W" ?Ὧ)

 ("a`" ?ὰ)
 ("a'" ?ά)
 ("e`" ?ὲ)
 ("e'" ?έ)
 ("h`" ?ὴ)
 ("h'" ?ή)
 ("i`" ?ὶ)
 ("i'" ?ί)
 ("o`" ?ὸ)
 ("o'" ?ό)
 ("u`" ?ὺ)
 ("u'" ?ύ)
 ("w`" ?ὼ)
 ("w'" ?ώ)

 ("a)|" ?ᾀ)
 ("a(|" ?ᾁ)
 ("a)`|" ?ᾂ)
 ("a(`|" ?ᾃ)
 ("a)'|" ?ᾄ)
 ("a('|" ?ᾅ)
 ("a)=|" ?ᾆ)
 ("a(=|" ?ᾇ)

 (")Ai" ?ᾈ)
 ("(Ai" ?ᾉ)
 (")`Ai" ?ᾊ)
 ("(`Ai" ?ᾋ)
 (")'Ai" ?ᾌ)
 ("('Ai" ?ᾍ)
 (")=Ai" ?ᾎ)
 ("(=Ai" ?ᾏ)

 ("h)|" ?ᾐ)
 ("h(|" ?ᾑ)
 ("h)`|" ?ᾒ)
 ("h(`|" ?ᾓ)
 ("h)'|" ?ᾔ)
 ("h('|" ?ᾕ)
 ("h)=|" ?ᾖ)
 ("h(=|" ?ᾗ)

 (")Hi" ?ᾘ)
 ("(Hi" ?ᾙ)
 (")`Hi" ?ᾚ)
 ("(`Hi" ?ᾛ)
 (")'Hi" ?ᾜ)
 ("('Hi" ?ᾝ)
 (")=Hi" ?ᾞ)
 ("(=Hi" ?ᾟ)

 ("w)|" ?ᾠ)
 ("w(|" ?ᾡ)
 ("w)`|" ?ᾢ)
 ("w(`|" ?ᾣ)
 ("w)'|" ?ᾤ)
 ("w('|" ?ᾥ)
 ("w)=|" ?ᾦ)
 ("w(=|" ?ᾧ)

 (")Wi" ?ᾨ)
 ("(Wi" ?ᾩ)
 (")`Wi" ?ᾪ)
 ("(`Wi" ?ᾫ)
 (")'Wi" ?ᾬ)
 ("('Wi" ?ᾭ)
 (")=Wi" ?ᾮ)
 ("(=Wi" ?ᾯ)

 ("a`|" ?ᾲ)
 ("a|" ?ᾳ)
 ("a'|" ?ᾴ)
 ("a=" ?ᾶ)
 ("a=|" ?ᾷ)

 ("`A" ?Ὰ)
 ("'A" ?Ά)
 ("Ai" ?ᾼ)

 (")" ?᾽) ; #x1fbd
 ("|" ?ι) ; #x1fbe
 (")" ?᾿) ; #x1fbf ; psili
 ("=" ?͂) ; #x0342
 ("=" ?῀) ; #x1fc0
 ("+=" ?῁) ; #x1fc1

 ("h`|" ?ῂ)
 ("h|" ?ῃ)
 ("h'|" ?ῄ)
 ("h=" ?ῆ)
 ("h=|" ?ῇ)

 ("`E" ?Ὲ)
 ("'E" ?Έ)

 ("`H" ?Ὴ)
 ("'H" ?Ή)
 ("Hi" ?ῌ)

 (")`" ?῍) ; #x1fcd
 (")'" ?῎) ; #x1fce
 (")=" ?῏) ; #x1fcf

 ("i+`" ?ῒ)
 ("i+'" ?ΐ)
 ("i=" ?ῖ)
 ("i+=" ?ῗ)

 ("`I" ?Ὶ)
 ("'I" ?Ί)

 ("(`" ?῝) ; #x1fdd
 ("('" ?῞) ; #x1fde
 ("(=" ?῟) ; #x1fdf

 ("u+`" ?ῢ)
 ("u+'" ?ΰ)

 ("r)" ?ῤ)
 ("r(" ?ῥ)

 ("u=" ?ῦ)
 ("u+=" ?ῧ)

 ("`U" ?Ὺ)
 ("'U" ?Ύ)

 ("`R" ?Ῥ)

 ("+`" ?῭) ; #x1fed
 ("+'" ?΅) ; #x1fee
 ("`" ?`) ; #x1fef ; varia

 ("w`|" ?ῲ)
 ("w|" ?ῳ)
 ("w'|" ?ῴ)
 ("w=" ?ῶ)
 ("w=|" ?ῷ)

 ("`O" ?Ὸ)
 ("'O" ?Ό)

 ("`W" ?Ὼ)
 ("'W" ?Ώ)
 ("Wi" ?ῼ)

 ("'" ?´) ; #x1ffd ; oxia
 ("(" ?῾) ;  #x1ffe ; dasia

 ("e=" "ε͂") ; epsilon + combining perispomeni (#x0342)
 ("o=" "ο͂") ; omicron + combining perispomeni (#x0342)

 ;; A quick hack for below dot
 ("_" "̣")
 )

(register-input-method
 "greek-ibycus4" "Greek"
 'robin-use-package "ib"
 "The Ibycus4 input method for classical Greek.")

;;; greek-babel-elot1000 is written by Alexej Kryukov <basileia@yandex.ru>

(robin-define-package "greek-babel-elot1000"
"The Babel compatible input method for classical Greek,
based on the ELOT1000 layout.

-------------------------------------
character     capital	      small
-------------------------------------
alpha		A		a
beta		B		b
gamma		G		g
delta		D		d
epsilon		E		e
zeta		Z		z
eta		H		h
theta		U		u
iota		I		i
kappa		K		k
lamda		L		l
mu		M		m
nu		H		n
xi		J		j
omicron		O		o
pi		P		p
rho		R		r
sigma		S		s
final sigma			w
tau		T		t
upsilon		Y		y
phi		F		f
chi		X		x
psi		C		c
omega		V		v
-------------------------------------
sampi				!
digamma		#
stigma				$
koppa		&		%
-------------------------------------

------------------------
mark		key
------------------------
ypogegrammeni	|
psili		>
dasia		<
oxia		;
varia		`
perispomeni	~  or  =
dialytika	:
ano teleia	W
colon           Q
erotimatiko	q
----------------------"

; PUNCTUATION MARKS - SYMBOLS (GREEK SPECIFIC)

 ("E$" ?€)  ; #x20AC
 (">>" ?») (";>" ?»)
 ("<<" ?«) (";<" ?«)
 ("Q" ?:)
 
 ("q" ?;) ; #x037E
 (";." ?·) ("W" ?·) ; #x0387
 ("'" ?᾽) ; #x1FBD
 ("--" ?–) ; #x2013
 ("---" ?—) ; #x2014

; GREEK DIACRITICS

 (":" ?¨) ; #x00A8
 (";" ?´) ; #x1FFD
 (":;" ?΅) (";:" ?΅) ; #x1FEE
 (":`" ?῭) ("`:" ?῭) ; #x1FED
 (":~" ?῁) ("~:" ?῁) (":=" ?῁) ("=:" ?῁) ; #x1FC1
 ("`" ?`) ; #x1FEF
 ("~" ?͂) ; #x0342
 ("~" ?῀) ; #x1FC0
 ("=" ?͂) ; #x0342
 ("=" ?῀) ; #x1FC0
 (">`" ?῍) ("`>" ?῍) ; #x1FCD
 ("<`" ?῝) ("`<" ?῝) ; #x1FDD
 (">;" ?῎) ; #x1FCE
 ("<;" ?῞) ; #x1FDE
 (">~" ?῏) (">=" ?῏) ("~>" ?῏) ("=>" ?῏) ; #x1FCF
 ("<~" ?῟) ("<=" ?῟) ("~<" ?῟) ("=<" ?῟) ; #x1FDF
 ("||" ?ͺ) ; #x037A

; GREEK LETTERS

 ("A" ?Α)
 ("B" ?Β)
 ("G" ?Γ)
 ("D" ?Δ)
 ("E" ?Ε)
 ("Z" ?Ζ)
 ("H" ?Η)
 ("U" ?Θ)
 ("I" ?Ι)
 ("K" ?Κ)
 ("L" ?Λ)
 ("M" ?Μ)
 ("N" ?Ν)
 ("J" ?Ξ)
 ("O" ?Ο)
 ("P" ?Π)
 ("R" ?Ρ)
 ("S" ?Σ)
 ("T" ?Τ)
 ("Y" ?Υ)
 ("F" ?Φ)
 ("X" ?Χ)
 ("C" ?Ψ)
 ("V" ?Ω)

 ("a" ?α)
 ("b" ?β)
 ("g" ?γ)
 ("d" ?δ)
 ("e" ?ε)
 ("z" ?ζ)
 ("h" ?η)
 ("u" ?θ)
 ("i" ?ι)
 ("k" ?κ)
 ("l" ?λ)
 ("m" ?μ)
 ("n" ?ν)
 ("j" ?ξ)
 ("o" ?ο)
 ("p" ?π)
 ("r" ?ρ)
 ("w" ?ς)
 ("s" ?σ)
 ("t" ?τ)
 ("y" ?υ)
 ("f" ?φ)
 ("x" ?χ)
 ("c" ?ψ)
 ("v" ?ω)

; ACCENTED GREEK LETTERS

 (";A" ?Ά) ; #x1FBB
 (";E" ?Έ) ; #x1FC9
 (";H" ?Ή) ; #x1FCB
 (";I" ?Ί) ; #x1FDB
 (";O" ?Ό) ; #x1FF9
 (";Y" ?Ύ) ; #x1FEB
 (";V" ?Ώ) ; #x1FFB
 (";a" ?ά) ; #x1F71
 (";e" ?έ) ; #x1F73
 (";h" ?ή) ; #x1F75
 (";i" ?ί) ; #x1F77
 (";o" ?ό) ; #x1F79
 (";y" ?ύ) ; #x1F7B
 (";v" ?ώ) ; #x1F7D

 ("`A" ?Ὰ)
 ("`E" ?Ὲ)
 ("`H" ?Ὴ)
 ("`I" ?Ὶ)
 ("`O" ?Ὸ)
 ("`Y" ?Ὺ)
 ("`V" ?Ὼ)
 ("`a" ?ὰ)
 ("`e" ?ὲ)
 ("`h" ?ὴ)
 ("`i" ?ὶ)
 ("`o" ?ὸ)
 ("`y" ?ὺ)
 ("`v" ?ὼ)

 ("~a" ?ᾶ) ("=a" ?ᾶ)
 ("~h" ?ῆ) ("=h" ?ῆ)
 ("~i" ?ῖ) ("=i" ?ῖ)
 ("~y" ?ῦ) ("=y" ?ῦ)
 ("~v" ?ῶ) ("=v" ?ῶ)

 (">A" ?Ἀ)
 (">E" ?Ἐ)
 (">H" ?Ἠ)
 (">I" ?Ἰ)
 (">O" ?Ὀ)
 (">V" ?Ὠ)
 (">a" ?ἀ)
 (">e" ?ἐ)
 (">h" ?ἠ)
 (">i" ?ἰ)
 (">o" ?ὀ)
 (">y" ?ὐ)
 (">v" ?ὠ)

 ("<A" ?Ἁ)
 ("<E" ?Ἑ)
 ("<H" ?Ἡ)
 ("<I" ?Ἱ)
 ("<O" ?Ὁ)
 ("<Y" ?Ὑ)
 ("<V" ?Ὡ)
 ("<a" ?ἁ)
 ("<e" ?ἑ)
 ("<h" ?ἡ)
 ("<i" ?ἱ)
 ("<o" ?ὁ)
 ("<y" ?ὑ)
 ("<v" ?ὡ)

 (">;A" ?Ἄ)
 (">;E" ?Ἔ)
 (">;H" ?Ἤ)
 (">;I" ?Ἴ)
 (">;O" ?Ὄ)
 (">;V" ?Ὤ)
 (">;a" ?ἄ)
 (">;e" ?ἔ)
 (">;h" ?ἤ)
 (">;i" ?ἴ)
 (">;o" ?ὄ)
 (">;y" ?ὔ)
 (">;v" ?ὤ)

 (">`A" ?Ἂ) ("`>A" ?Ἂ)
 (">`E" ?Ἒ) ("`>E" ?Ἒ)
 (">`H" ?Ἢ) ("`>H" ?Ἢ)
 (">`I" ?Ἲ) ("`>I" ?Ἲ)
 (">`O" ?Ὂ) ("`>O" ?Ὂ)
 (">`V" ?Ὢ) ("`>V" ?Ὢ)
 (">`a" ?ἂ) ("`>a" ?ἂ)
 (">`e" ?ἒ) ("`>e" ?ἒ)
 (">`h" ?ἢ) ("`>h" ?ἢ)
 (">`i" ?ἲ) ("`>i" ?ἲ)
 (">`o" ?ὂ) ("`>o" ?ὂ)
 (">`y" ?ὒ) ("`>y" ?ὒ)
 (">`v" ?ὢ) ("`>v" ?ὢ)

 (">~A" ?Ἆ) (">=A" ?Ἆ) ("~>A" ?Ἆ) ("=>A" ?Ἆ)
 (">~H" ?Ἦ) (">=H" ?Ἦ) ("~>H" ?Ἦ) ("=>H" ?Ἦ)
 (">~I" ?Ἶ) (">=I" ?Ἶ) ("~>I" ?Ἶ) ("=>I" ?Ἶ)
 (">~W" ?Ὦ) (">=W" ?Ὦ) ("~>W" ?Ὦ) ("=>W" ?Ὦ)
 (">~a" ?ἆ) (">=a" ?ἆ) ("~>a" ?ἆ) ("=>a" ?ἆ)
 (">~h" ?ἦ) (">=h" ?ἦ) ("~>h" ?ἦ) ("=>h" ?ἦ)
 (">~i" ?ἶ) (">=i" ?ἶ) ("~>i" ?ἶ) ("=>i" ?ἶ)
 (">~y" ?ὖ) (">=y" ?ὖ) ("~>y" ?ὖ) ("=>y" ?ὖ)
 (">~v" ?ὦ) (">=v" ?ὦ) ("~>v" ?ὦ) ("=>v" ?ὦ)

 ("<;A" ?Ἅ)
 ("<;E" ?Ἕ)
 ("<;H" ?Ἥ)
 ("<;I" ?Ἵ)
 ("<;O" ?Ὅ)
 ("<;Y" ?Ὕ)
 ("<;V" ?Ὥ)
 ("<;a" ?ἅ)
 ("<;e" ?ἕ)
 ("<;h" ?ἥ)
 ("<;i" ?ἵ)
 ("<;o" ?ὅ)
 ("<;y" ?ὕ)
 ("<;v" ?ὥ)

 ("<`A" ?Ἃ) ("`<A" ?Ἃ)
 ("<`E" ?Ἓ) ("`<E" ?Ἓ)
 ("<`H" ?Ἣ) ("`<H" ?Ἣ)
 ("<`I" ?Ἳ) ("`<I" ?Ἳ)
 ("<`O" ?Ὃ) ("`<O" ?Ὃ)
 ("<`Y" ?Ὓ) ("`<Y" ?Ὓ)
 ("<`V" ?Ὣ) ("`<V" ?Ὣ)
 ("<`a" ?ἃ) ("`<a" ?ἃ)
 ("<`e" ?ἓ) ("`<e" ?ἓ)
 ("<`h" ?ἣ) ("`<h" ?ἣ)
 ("<`i" ?ἳ) ("`<i" ?ἳ)
 ("<`o" ?ὃ) ("`<o" ?ὃ)
 ("<`y" ?ὓ) ("`<y" ?ὓ)
 ("<`v" ?ὣ) ("`<v" ?ὣ)

 ("<~A" ?Ἇ) ("<=A" ?Ἇ) ("~<A" ?Ἇ) ("=<A" ?Ἇ)
 ("<~H" ?Ἧ) ("<=H" ?Ἧ) ("~<H" ?Ἧ) ("=<H" ?Ἧ)
 ("<~I" ?Ἷ) ("<=I" ?Ἷ) ("~<I" ?Ἷ) ("=<I" ?Ἷ)
 ("<~Y" ?Ὗ) ("<=Y" ?Ὗ) ("~<Y" ?Ὗ) ("=<Y" ?Ὗ)
 ("<~W" ?Ὧ) ("<=W" ?Ὧ) ("~<W" ?Ὧ) ("=<W" ?Ὧ)
 ("<~a" ?ἇ) ("<=a" ?ἇ) ("~<a" ?ἇ) ("=<a" ?ἇ)
 ("<~h" ?ἧ) ("<=h" ?ἧ) ("~<h" ?ἧ) ("=<h" ?ἧ)
 ("<~i" ?ἷ) ("<=i" ?ἷ) ("~<i" ?ἷ) ("=<i" ?ἷ)
 ("<~y" ?ὗ) ("<=y" ?ὗ) ("~<y" ?ὗ) ("=<y" ?ὗ)
 ("<~v" ?ὧ) ("<=v" ?ὧ) ("~<v" ?ὧ) ("=<v" ?ὧ)

; GREEK ACCENTED LETTERS WITH YPOGEGRAMMENI

 ("A|" ?ᾼ)
 ("H|" ?ῌ)
 ("V|" ?ῼ)
 ("a|" ?ᾳ)
 ("h|" ?ῃ)
 ("v|" ?ῳ)

 (";a|" ?ᾴ)
 (";h|" ?ῄ)
 (";v|" ?ῴ)

 ("`a|" ?ᾲ)
 ("`h|" ?ῂ)
 ("`v|" ?ῲ)

 ("~a|" ?ᾷ) ("=a|" ?ᾷ)
 ("~h|" ?ῇ) ("=h|" ?ῇ)
 ("~v|" ?ῷ) ("=v|" ?ῷ)

 (">A|" ?ᾈ)
 (">H|" ?ᾘ)
 (">V|" ?ᾨ)
 (">a|" ?ᾀ)
 (">h|" ?ᾐ)
 (">v|" ?ᾠ)

 ("<A|" ?ᾉ)
 ("<H|" ?ᾙ)
 ("<V|" ?ᾩ)
 ("<a|" ?ᾁ)
 ("<h|" ?ᾑ)
 ("<v|" ?ᾡ)

 (">;A|" ?ᾌ)
 (">;H|" ?ᾜ)
 (">;V|" ?ᾬ)
 (">;a|" ?ᾄ)
 (">;h|" ?ᾔ)
 (">;v|" ?ᾤ)

 ("<`A|" ?ᾋ) ("`<A|" ?ᾋ)
 ("<`H|" ?ᾛ) ("`<H|" ?ᾛ)
 ("<`V|" ?ᾫ) ("`<V|" ?ᾫ)
 ("<`a|" ?ᾃ) ("`<a|" ?ᾃ)
 ("<`h|" ?ᾓ) ("`<h|" ?ᾓ)
 ("<`v|" ?ᾣ) ("`<v|" ?ᾣ)

 ("<~A|" ?ᾏ) ("~<A|" ?ᾏ) ("<=A|" ?ᾏ) ("=<A|" ?ᾏ)
 ("<~H|" ?ᾟ) ("~<H|" ?ᾟ) ("<=H|" ?ᾟ) ("=<H|" ?ᾟ)
 ("<~V|" ?ᾯ) ("~<V|" ?ᾯ) ("<=V|" ?ᾯ) ("=<V|" ?ᾯ)
 ("<~a|" ?ᾇ) ("~<a|" ?ᾇ) ("<=a|" ?ᾇ) ("=<a|" ?ᾇ)
 ("<~h|" ?ᾗ) ("~<h|" ?ᾗ) ("<=h|" ?ᾗ) ("=<h|" ?ᾗ)
 ("<~v|" ?ᾧ) ("~<v|" ?ᾧ) ("<=v|" ?ᾧ) ("=<v|" ?ᾧ)

; YPSILON AND IOTA WITH DIALYTIKA

 (":i" ?ϊ)
 (":y" ?ϋ)
 (":I" ?Ϊ)
 (":Y" ?Ϋ)
 (":;i" ?ΐ) (";:i" ?ΐ) ; #x1FD3
 (":;y" ?ΰ) (";:y" ?ΰ) ; #x1FE3
 (":`i" ?ῒ) (";`i" ?ῒ)
 (":`y" ?ῢ) (";`y" ?ῢ)
 (":~i" ?ῗ) ("~:i" ?ῗ) (":=i" ?ῗ) ("=:i" ?ῗ)
 (":~y" ?ῧ) ("~:y" ?ῧ) (":=y" ?ῧ) ("=:y" ?ῧ)
 
; GREEK ACCENTED LETTERS WITH MACRON AND BREVE
 
 ("-a" ?ᾱ)
 ("-i" ?ῑ)
 ("-y" ?ῡ)
 ("-A" ?Ᾱ)
 ("-I" ?Ῑ)
 ("-Y" ?Ῡ)
 ("^a" ?ᾰ)
 ("^i" ?ῐ)
 ("^y" ?ῠ)
 ("^A" ?Ᾰ)
 ("^I" ?Ῐ)
 ("^Y" ?Ῠ)

; GREEK LETTER RHO WITH BREATHINGS

 (">r" ?ῤ)
 ("<r" ?ῥ)
 ("<R" ?Ῥ)

; NUMERIC AND ARCHAIC SYMBOLS

 (";#" ?ʹ) ; #x0374
 (";##" ?͵) ; #x0375
 ("#ST" ?Ϛ) ; #x03DA
 ("#st" ?ϛ) ; #x03DB
 ("#F" ?Ϝ) ; #x03DC
 ("#f" ?ϝ) ; #x03DD
 ("#Q" ?Ϟ) ; #x03DE
 ("#q" ?ϟ) ; #x03DF
 ("#SP" ?Ϡ) ; #x03E0
 ("#sp" ?ϡ) ; #x03E1
 ("D$" ?₯) ; #x20AF
; ("#Q" ?Ϙ) ; #x03D8
; ("#q" ?ϙ) ; #x03D9

; ALTERNATE GLYPH VARIANTS

 ("&&" ?ϗ) ; #x03D7
 (";b" ?ϐ) ; #x03D0
 (";u" ?ϑ) ; #x03D1
 (";f" ?ϕ) ; #x03D5
 (";p" ?ϖ) ; #x03D6
 (";k" ?ϰ) ; #x03F0
 (";r" ?ϱ) ; #x03F1
 (";U" ?ϴ) ; #x03F4

 ("e~" "ε͂") ("e=" "ε͂") ; epsilon + combining perispomeni (#x0342)
 ("o~" "ο͂") ("o=" "ο͂") ; omicron + combining perispomeni (#x0342)
)

(register-input-method
 "greek-babel-elot1000" "Greek"
 'robin-use-package "el"
 "The Babel compatible input method for classical Greek,
 based on the ELOT 1000 layout.")

;; a quick hack for {epsilon|omicron} + perispomeni

(defun greek-compose-perispomeni nil
  (interactive)
  (let ((epsilon #x03b5)
	(omicron #x03bf)
	(perispomeni #x0342))
    (and robin-mode
	 (memq (preceding-char) (list epsilon omicron))
	 (not (find-composition (1- (point))))
	 (compose-region
	  (1- (point))
	  (progn (insert perispomeni) (point))))))

(global-set-key (vector #x0342) 'greek-compose-perispomeni)

;;; greek.el ends here
